# coding: utf-8

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages  # noqa: E501

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import pulpcore.client.pulp_ansible
from pulpcore.client.pulp_ansible.api.ansible_collections_api import AnsibleCollectionsApi  # noqa: E501
from pulpcore.client.pulp_ansible.rest import ApiException


class TestAnsibleCollectionsApi(unittest.TestCase):
    """AnsibleCollectionsApi unit test stubs"""

    def setUp(self):
        self.api = pulpcore.client.pulp_ansible.api.ansible_collections_api.AnsibleCollectionsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_role(self):
        """Test case for add_role

        """
        pass

    def test_list(self):
        """Test case for list

        List collections  # noqa: E501
        """
        pass

    def test_list_roles(self):
        """Test case for list_roles

        """
        pass

    def test_my_permissions(self):
        """Test case for my_permissions

        """
        pass

    def test_remove_role(self):
        """Test case for remove_role

        """
        pass

    def test_upload_collection(self):
        """Test case for upload_collection

        Upload a collection  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages  # noqa: E501

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from pulpcore.client.pulp_ansible.configuration import Configuration


class CollectionVersionListResponse(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'version': 'str',
        'href': 'str',
        'created_at': 'datetime',
        'updated_at': 'datetime',
        'requires_ansible': 'str',
        'marks': 'list[str]'
    }

    attribute_map = {
        'version': 'version',
        'href': 'href',
        'created_at': 'created_at',
        'updated_at': 'updated_at',
        'requires_ansible': 'requires_ansible',
        'marks': 'marks'
    }

    def __init__(self, version=None, href=None, created_at=None, updated_at=None, requires_ansible=None, marks=None, local_vars_configuration=None):  # noqa: E501
        """CollectionVersionListResponse - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._version = None
        self._href = None
        self._created_at = None
        self._updated_at = None
        self._requires_ansible = None
        self._marks = None
        self.discriminator = None

        if version is not None:
            self.version = version
        if href is not None:
            self.href = href
        self.created_at = created_at
        self.updated_at = updated_at
        self.requires_ansible = requires_ansible
        if marks is not None:
            self.marks = marks

    @property
    def version(self):
        """Gets the version of this CollectionVersionListResponse.  # noqa: E501


        :return: The version of this CollectionVersionListResponse.  # noqa: E501
        :rtype: str
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this CollectionVersionListResponse.


        :param version: The version of this CollectionVersionListResponse.  # noqa: E501
        :type: str
        """

        self._version = version

    @property
    def href(self):
        """Gets the href of this CollectionVersionListResponse.  # noqa: E501

        Get href.  # noqa: E501

        :return: The href of this CollectionVersionListResponse.  # noqa: E501
        :rtype: str
        """
        return self._href

    @href.setter
    def href(self, href):
        """Sets the href of this CollectionVersionListResponse.

        Get href.  # noqa: E501

        :param href: The href of this CollectionVersionListResponse.  # noqa: E501
        :type: str
        """

        self._href = href

    @property
    def created_at(self):
        """Gets the created_at of this CollectionVersionListResponse.  # noqa: E501


        :return: The created_at of this CollectionVersionListResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this CollectionVersionListResponse.


        :param created_at: The created_at of this CollectionVersionListResponse.  # noqa: E501
        :type: datetime
        """
        if self.local_vars_configuration.client_side_validation and created_at is None:  # noqa: E501
            raise ValueError("Invalid value for `created_at`, must not be `None`")  # noqa: E501

        self._created_at = created_at

    @property
    def updated_at(self):
        """Gets the updated_at of this CollectionVersionListResponse.  # noqa: E501


        :return: The updated_at of this CollectionVersionListResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_at

    @updated_at.setter
    def updated_at(self, updated_at):
        """Sets the updated_at of this CollectionVersionListResponse.


        :param updated_at: The updated_at of this CollectionVersionListResponse.  # noqa: E501
        :type: datetime
        """
        if self.local_vars_configuration.client_side_validation and updated_at is None:  # noqa: E501
            raise ValueError("Invalid value for `updated_at`, must not be `None`")  # noqa: E501

        self._updated_at = updated_at

    @property
    def requires_ansible(self):
        """Gets the requires_ansible of this CollectionVersionListResponse.  # noqa: E501


        :return: The requires_ansible of this CollectionVersionListResponse.  # noqa: E501
        :rtype: str
        """
        return self._requires_ansible

    @requires_ansible.setter
    def requires_ansible(self, requires_ansible):
        """Sets the requires_ansible of this CollectionVersionListResponse.


        :param requires_ansible: The requires_ansible of this CollectionVersionListResponse.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                requires_ansible is not None and len(requires_ansible) > 255):
            raise ValueError("Invalid value for `requires_ansible`, length must be less than or equal to `255`")  # noqa: E501

        self._requires_ansible = requires_ansible

    @property
    def marks(self):
        """Gets the marks of this CollectionVersionListResponse.  # noqa: E501

        Get a list of mark values filtering only those in the current repo.  # noqa: E501

        :return: The marks of this CollectionVersionListResponse.  # noqa: E501
        :rtype: list[str]
        """
        return self._marks

    @marks.setter
    def marks(self, marks):
        """Sets the marks of this CollectionVersionListResponse.

        Get a list of mark values filtering only those in the current repo.  # noqa: E501

        :param marks: The marks of this CollectionVersionListResponse.  # noqa: E501
        :type: list[str]
        """

        self._marks = marks

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CollectionVersionListResponse):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CollectionVersionListResponse):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages  # noqa: E501

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import pulpcore.client.pulp_ansible
from pulpcore.client.pulp_ansible.models.paginatedansible_ansible_namespace_metadata_response_list import PaginatedansibleAnsibleNamespaceMetadataResponseList  # noqa: E501
from pulpcore.client.pulp_ansible.rest import ApiException

class TestPaginatedansibleAnsibleNamespaceMetadataResponseList(unittest.TestCase):
    """PaginatedansibleAnsibleNamespaceMetadataResponseList unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test PaginatedansibleAnsibleNamespaceMetadataResponseList
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = pulpcore.client.pulp_ansible.models.paginatedansible_ansible_namespace_metadata_response_list.PaginatedansibleAnsibleNamespaceMetadataResponseList()  # noqa: E501
        if include_optional :
            return PaginatedansibleAnsibleNamespaceMetadataResponseList(
                count = 123, 
                next = 'http://api.example.org/accounts/?offset=400&limit=100', 
                previous = 'http://api.example.org/accounts/?offset=200&limit=100', 
                results = [
                    pulpcore.client.pulp_ansible.models.ansible/ansible_namespace_metadata_response.ansible.AnsibleNamespaceMetadataResponse(
                        pulp_href = '0', 
                        name = 'a', 
                        company = '0', 
                        email = '0', 
                        description = '0', 
                        resources = '0', 
                        links = [
                            pulpcore.client.pulp_ansible.models.namespace_link_response.NamespaceLinkResponse(
                                url = '0', 
                                name = '0', )
                            ], 
                        avatar_sha256 = '0', 
                        avatar_url = '0', 
                        metadata_sha256 = '0', )
                    ]
            )
        else :
            return PaginatedansibleAnsibleNamespaceMetadataResponseList(
        )

    def testPaginatedansibleAnsibleNamespaceMetadataResponseList(self):
        """Test PaginatedansibleAnsibleNamespaceMetadataResponseList"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages  # noqa: E501

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import pulpcore.client.pulp_ansible
from pulpcore.client.pulp_ansible.models.collection_version_search_list import CollectionVersionSearchList  # noqa: E501
from pulpcore.client.pulp_ansible.rest import ApiException

class TestCollectionVersionSearchList(unittest.TestCase):
    """CollectionVersionSearchList unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test CollectionVersionSearchList
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = pulpcore.client.pulp_ansible.models.collection_version_search_list.CollectionVersionSearchList()  # noqa: E501
        if include_optional :
            return CollectionVersionSearchList(
                repository = pulpcore.client.pulp_ansible.models.repository.Repository(
                    pulp_labels = {
                        'key' : '0'
                        }, 
                    name = '0', 
                    description = '0', 
                    retain_repo_versions = 1, 
                    remote = '0', ), 
                collection_version = None, 
                namespace_metadata = null, 
                is_highest = True, 
                is_deprecated = True, 
                is_signed = True
            )
        else :
            return CollectionVersionSearchList(
                repository = pulpcore.client.pulp_ansible.models.repository.Repository(
                    pulp_labels = {
                        'key' : '0'
                        }, 
                    name = '0', 
                    description = '0', 
                    retain_repo_versions = 1, 
                    remote = '0', ),
                collection_version = None,
                namespace_metadata = null,
                is_highest = True,
                is_deprecated = True,
                is_signed = True,
        )

    def testCollectionVersionSearchList(self):
        """Test CollectionVersionSearchList"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages  # noqa: E501

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from pulpcore.client.pulp_ansible.configuration import Configuration


class TaskResponse(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'pulp_href': 'str',
        'pulp_created': 'datetime',
        'state': 'str',
        'name': 'str',
        'logging_cid': 'str',
        'started_at': 'datetime',
        'finished_at': 'datetime',
        'error': 'dict(str, object)',
        'worker': 'str',
        'parent_task': 'str',
        'child_tasks': 'list[str]',
        'task_group': 'str',
        'progress_reports': 'list[ProgressReportResponse]',
        'created_resources': 'list[str]',
        'reserved_resources_record': 'list[str]'
    }

    attribute_map = {
        'pulp_href': 'pulp_href',
        'pulp_created': 'pulp_created',
        'state': 'state',
        'name': 'name',
        'logging_cid': 'logging_cid',
        'started_at': 'started_at',
        'finished_at': 'finished_at',
        'error': 'error',
        'worker': 'worker',
        'parent_task': 'parent_task',
        'child_tasks': 'child_tasks',
        'task_group': 'task_group',
        'progress_reports': 'progress_reports',
        'created_resources': 'created_resources',
        'reserved_resources_record': 'reserved_resources_record'
    }

    def __init__(self, pulp_href=None, pulp_created=None, state=None, name=None, logging_cid=None, started_at=None, finished_at=None, error=None, worker=None, parent_task=None, child_tasks=None, task_group=None, progress_reports=None, created_resources=None, reserved_resources_record=None, local_vars_configuration=None):  # noqa: E501
        """TaskResponse - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._pulp_href = None
        self._pulp_created = None
        self._state = None
        self._name = None
        self._logging_cid = None
        self._started_at = None
        self._finished_at = None
        self._error = None
        self._worker = None
        self._parent_task = None
        self._child_tasks = None
        self._task_group = None
        self._progress_reports = None
        self._created_resources = None
        self._reserved_resources_record = None
        self.discriminator = None

        if pulp_href is not None:
            self.pulp_href = pulp_href
        if pulp_created is not None:
            self.pulp_created = pulp_created
        if state is not None:
            self.state = state
        self.name = name
        self.logging_cid = logging_cid
        if started_at is not None:
            self.started_at = started_at
        if finished_at is not None:
            self.finished_at = finished_at
        if error is not None:
            self.error = error
        if worker is not None:
            self.worker = worker
        if parent_task is not None:
            self.parent_task = parent_task
        if child_tasks is not None:
            self.child_tasks = child_tasks
        if task_group is not None:
            self.task_group = task_group
        if progress_reports is not None:
            self.progress_reports = progress_reports
        if created_resources is not None:
            self.created_resources = created_resources
        if reserved_resources_record is not None:
            self.reserved_resources_record = reserved_resources_record

    @property
    def pulp_href(self):
        """Gets the pulp_href of this TaskResponse.  # noqa: E501


        :return: The pulp_href of this TaskResponse.  # noqa: E501
        :rtype: str
        """
        return self._pulp_href

    @pulp_href.setter
    def pulp_href(self, pulp_href):
        """Sets the pulp_href of this TaskResponse.


        :param pulp_href: The pulp_href of this TaskResponse.  # noqa: E501
        :type: str
        """

        self._pulp_href = pulp_href

    @property
    def pulp_created(self):
        """Gets the pulp_created of this TaskResponse.  # noqa: E501

        Timestamp of creation.  # noqa: E501

        :return: The pulp_created of this TaskResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._pulp_created

    @pulp_created.setter
    def pulp_created(self, pulp_created):
        """Sets the pulp_created of this TaskResponse.

        Timestamp of creation.  # noqa: E501

        :param pulp_created: The pulp_created of this TaskResponse.  # noqa: E501
        :type: datetime
        """

        self._pulp_created = pulp_created

    @property
    def state(self):
        """Gets the state of this TaskResponse.  # noqa: E501

        The current state of the task. The possible values include: 'waiting', 'skipped', 'running', 'completed', 'failed', 'canceled' and 'canceling'.  # noqa: E501

        :return: The state of this TaskResponse.  # noqa: E501
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this TaskResponse.

        The current state of the task. The possible values include: 'waiting', 'skipped', 'running', 'completed', 'failed', 'canceled' and 'canceling'.  # noqa: E501

        :param state: The state of this TaskResponse.  # noqa: E501
        :type: str
        """

        self._state = state

    @property
    def name(self):
        """Gets the name of this TaskResponse.  # noqa: E501

        The name of task.  # noqa: E501

        :return: The name of this TaskResponse.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this TaskResponse.

        The name of task.  # noqa: E501

        :param name: The name of this TaskResponse.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def logging_cid(self):
        """Gets the logging_cid of this TaskResponse.  # noqa: E501

        The logging correlation id associated with this task  # noqa: E501

        :return: The logging_cid of this TaskResponse.  # noqa: E501
        :rtype: str
        """
        return self._logging_cid

    @logging_cid.setter
    def logging_cid(self, logging_cid):
        """Sets the logging_cid of this TaskResponse.

        The logging correlation id associated with this task  # noqa: E501

        :param logging_cid: The logging_cid of this TaskResponse.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and logging_cid is None:  # noqa: E501
            raise ValueError("Invalid value for `logging_cid`, must not be `None`")  # noqa: E501

        self._logging_cid = logging_cid

    @property
    def started_at(self):
        """Gets the started_at of this TaskResponse.  # noqa: E501

        Timestamp of the when this task started execution.  # noqa: E501

        :return: The started_at of this TaskResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._started_at

    @started_at.setter
    def started_at(self, started_at):
        """Sets the started_at of this TaskResponse.

        Timestamp of the when this task started execution.  # noqa: E501

        :param started_at: The started_at of this TaskResponse.  # noqa: E501
        :type: datetime
        """

        self._started_at = started_at

    @property
    def finished_at(self):
        """Gets the finished_at of this TaskResponse.  # noqa: E501

        Timestamp of the when this task stopped execution.  # noqa: E501

        :return: The finished_at of this TaskResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._finished_at

    @finished_at.setter
    def finished_at(self, finished_at):
        """Sets the finished_at of this TaskResponse.

        Timestamp of the when this task stopped execution.  # noqa: E501

        :param finished_at: The finished_at of this TaskResponse.  # noqa: E501
        :type: datetime
        """

        self._finished_at = finished_at

    @property
    def error(self):
        """Gets the error of this TaskResponse.  # noqa: E501

        A JSON Object of a fatal error encountered during the execution of this task.  # noqa: E501

        :return: The error of this TaskResponse.  # noqa: E501
        :rtype: dict(str, object)
        """
        return self._error

    @error.setter
    def error(self, error):
        """Sets the error of this TaskResponse.

        A JSON Object of a fatal error encountered during the execution of this task.  # noqa: E501

        :param error: The error of this TaskResponse.  # noqa: E501
        :type: dict(str, object)
        """

        self._error = error

    @property
    def worker(self):
        """Gets the worker of this TaskResponse.  # noqa: E501

        The worker associated with this task. This field is empty if a worker is not yet assigned.  # noqa: E501

        :return: The worker of this TaskResponse.  # noqa: E501
        :rtype: str
        """
        return self._worker

    @worker.setter
    def worker(self, worker):
        """Sets the worker of this TaskResponse.

        The worker associated with this task. This field is empty if a worker is not yet assigned.  # noqa: E501

        :param worker: The worker of this TaskResponse.  # noqa: E501
        :type: str
        """

        self._worker = worker

    @property
    def parent_task(self):
        """Gets the parent_task of this TaskResponse.  # noqa: E501

        The parent task that spawned this task.  # noqa: E501

        :return: The parent_task of this TaskResponse.  # noqa: E501
        :rtype: str
        """
        return self._parent_task

    @parent_task.setter
    def parent_task(self, parent_task):
        """Sets the parent_task of this TaskResponse.

        The parent task that spawned this task.  # noqa: E501

        :param parent_task: The parent_task of this TaskResponse.  # noqa: E501
        :type: str
        """

        self._parent_task = parent_task

    @property
    def child_tasks(self):
        """Gets the child_tasks of this TaskResponse.  # noqa: E501

        Any tasks spawned by this task.  # noqa: E501

        :return: The child_tasks of this TaskResponse.  # noqa: E501
        :rtype: list[str]
        """
        return self._child_tasks

    @child_tasks.setter
    def child_tasks(self, child_tasks):
        """Sets the child_tasks of this TaskResponse.

        Any tasks spawned by this task.  # noqa: E501

        :param child_tasks: The child_tasks of this TaskResponse.  # noqa: E501
        :type: list[str]
        """

        self._child_tasks = child_tasks

    @property
    def task_group(self):
        """Gets the task_group of this TaskResponse.  # noqa: E501

        The task group that this task is a member of.  # noqa: E501

        :return: The task_group of this TaskResponse.  # noqa: E501
        :rtype: str
        """
        return self._task_group

    @task_group.setter
    def task_group(self, task_group):
        """Sets the task_group of this TaskResponse.

        The task group that this task is a member of.  # noqa: E501

        :param task_group: The task_group of this TaskResponse.  # noqa: E501
        :type: str
        """

        self._task_group = task_group

    @property
    def progress_reports(self):
        """Gets the progress_reports of this TaskResponse.  # noqa: E501


        :return: The progress_reports of this TaskResponse.  # noqa: E501
        :rtype: list[ProgressReportResponse]
        """
        return self._progress_reports

    @progress_reports.setter
    def progress_reports(self, progress_reports):
        """Sets the progress_reports of this TaskResponse.


        :param progress_reports: The progress_reports of this TaskResponse.  # noqa: E501
        :type: list[ProgressReportResponse]
        """

        self._progress_reports = progress_reports

    @property
    def created_resources(self):
        """Gets the created_resources of this TaskResponse.  # noqa: E501

        Resources created by this task.  # noqa: E501

        :return: The created_resources of this TaskResponse.  # noqa: E501
        :rtype: list[str]
        """
        return self._created_resources

    @created_resources.setter
    def created_resources(self, created_resources):
        """Sets the created_resources of this TaskResponse.

        Resources created by this task.  # noqa: E501

        :param created_resources: The created_resources of this TaskResponse.  # noqa: E501
        :type: list[str]
        """

        self._created_resources = created_resources

    @property
    def reserved_resources_record(self):
        """Gets the reserved_resources_record of this TaskResponse.  # noqa: E501

        A list of resources required by that task.  # noqa: E501

        :return: The reserved_resources_record of this TaskResponse.  # noqa: E501
        :rtype: list[str]
        """
        return self._reserved_resources_record

    @reserved_resources_record.setter
    def reserved_resources_record(self, reserved_resources_record):
        """Sets the reserved_resources_record of this TaskResponse.

        A list of resources required by that task.  # noqa: E501

        :param reserved_resources_record: The reserved_resources_record of this TaskResponse.  # noqa: E501
        :type: list[str]
        """

        self._reserved_resources_record = reserved_resources_record

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TaskResponse):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, TaskResponse):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages  # noqa: E501

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import pulpcore.client.pulp_ansible
from pulpcore.client.pulp_ansible.models.task_response import TaskResponse  # noqa: E501
from pulpcore.client.pulp_ansible.rest import ApiException

class TestTaskResponse(unittest.TestCase):
    """TaskResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test TaskResponse
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = pulpcore.client.pulp_ansible.models.task_response.TaskResponse()  # noqa: E501
        if include_optional :
            return TaskResponse(
                pulp_href = '0', 
                pulp_created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                state = '0', 
                name = '0', 
                logging_cid = '0', 
                started_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                finished_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                error = {
                    'key' : None
                    }, 
                worker = '0', 
                parent_task = '0', 
                child_tasks = [
                    '0'
                    ], 
                task_group = '0', 
                progress_reports = [
                    pulpcore.client.pulp_ansible.models.progress_report_response.ProgressReportResponse(
                        message = '0', 
                        code = '0', 
                        state = '0', 
                        total = 56, 
                        done = 56, 
                        suffix = '0', )
                    ], 
                created_resources = [
                    '0'
                    ], 
                reserved_resources_record = [
                    '0'
                    ]
            )
        else :
            return TaskResponse(
                name = '0',
                logging_cid = '0',
        )

    def testTaskResponse(self):
        """Test TaskResponse"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages  # noqa: E501

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from pulpcore.client.pulp_ansible.configuration import Configuration


class PatchedansibleAnsibleNamespaceMetadata(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'name': 'str',
        'company': 'str',
        'email': 'str',
        'description': 'str',
        'resources': 'str',
        'links': 'list[NamespaceLink]',
        'avatar': 'file'
    }

    attribute_map = {
        'name': 'name',
        'company': 'company',
        'email': 'email',
        'description': 'description',
        'resources': 'resources',
        'links': 'links',
        'avatar': 'avatar'
    }

    def __init__(self, name=None, company=None, email=None, description=None, resources=None, links=None, avatar=None, local_vars_configuration=None):  # noqa: E501
        """PatchedansibleAnsibleNamespaceMetadata - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._name = None
        self._company = None
        self._email = None
        self._description = None
        self._resources = None
        self._links = None
        self._avatar = None
        self.discriminator = None

        if name is not None:
            self.name = name
        if company is not None:
            self.company = company
        if email is not None:
            self.email = email
        if description is not None:
            self.description = description
        if resources is not None:
            self.resources = resources
        if links is not None:
            self.links = links
        if avatar is not None:
            self.avatar = avatar

    @property
    def name(self):
        """Gets the name of this PatchedansibleAnsibleNamespaceMetadata.  # noqa: E501

        Required named, only accepts lowercase, numbers and underscores.  # noqa: E501

        :return: The name of this PatchedansibleAnsibleNamespaceMetadata.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this PatchedansibleAnsibleNamespaceMetadata.

        Required named, only accepts lowercase, numbers and underscores.  # noqa: E501

        :param name: The name of this PatchedansibleAnsibleNamespaceMetadata.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                name is not None and len(name) > 64):
            raise ValueError("Invalid value for `name`, length must be less than or equal to `64`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                name is not None and len(name) < 3):
            raise ValueError("Invalid value for `name`, length must be greater than or equal to `3`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                name is not None and not re.search(r'^(?!.*__)[a-z]+[0-9a-z_]*$', name)):  # noqa: E501
            raise ValueError(r"Invalid value for `name`, must be a follow pattern or equal to `/^(?!.*__)[a-z]+[0-9a-z_]*$/`")  # noqa: E501

        self._name = name

    @property
    def company(self):
        """Gets the company of this PatchedansibleAnsibleNamespaceMetadata.  # noqa: E501

        Optional namespace company owner.  # noqa: E501

        :return: The company of this PatchedansibleAnsibleNamespaceMetadata.  # noqa: E501
        :rtype: str
        """
        return self._company

    @company.setter
    def company(self, company):
        """Sets the company of this PatchedansibleAnsibleNamespaceMetadata.

        Optional namespace company owner.  # noqa: E501

        :param company: The company of this PatchedansibleAnsibleNamespaceMetadata.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                company is not None and len(company) > 64):
            raise ValueError("Invalid value for `company`, length must be less than or equal to `64`")  # noqa: E501

        self._company = company

    @property
    def email(self):
        """Gets the email of this PatchedansibleAnsibleNamespaceMetadata.  # noqa: E501

        Optional namespace contact email.  # noqa: E501

        :return: The email of this PatchedansibleAnsibleNamespaceMetadata.  # noqa: E501
        :rtype: str
        """
        return self._email

    @email.setter
    def email(self, email):
        """Sets the email of this PatchedansibleAnsibleNamespaceMetadata.

        Optional namespace contact email.  # noqa: E501

        :param email: The email of this PatchedansibleAnsibleNamespaceMetadata.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                email is not None and len(email) > 256):
            raise ValueError("Invalid value for `email`, length must be less than or equal to `256`")  # noqa: E501

        self._email = email

    @property
    def description(self):
        """Gets the description of this PatchedansibleAnsibleNamespaceMetadata.  # noqa: E501

        Optional short description.  # noqa: E501

        :return: The description of this PatchedansibleAnsibleNamespaceMetadata.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this PatchedansibleAnsibleNamespaceMetadata.

        Optional short description.  # noqa: E501

        :param description: The description of this PatchedansibleAnsibleNamespaceMetadata.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                description is not None and len(description) > 256):
            raise ValueError("Invalid value for `description`, length must be less than or equal to `256`")  # noqa: E501

        self._description = description

    @property
    def resources(self):
        """Gets the resources of this PatchedansibleAnsibleNamespaceMetadata.  # noqa: E501

        Optional resource page in markdown format.  # noqa: E501

        :return: The resources of this PatchedansibleAnsibleNamespaceMetadata.  # noqa: E501
        :rtype: str
        """
        return self._resources

    @resources.setter
    def resources(self, resources):
        """Sets the resources of this PatchedansibleAnsibleNamespaceMetadata.

        Optional resource page in markdown format.  # noqa: E501

        :param resources: The resources of this PatchedansibleAnsibleNamespaceMetadata.  # noqa: E501
        :type: str
        """

        self._resources = resources

    @property
    def links(self):
        """Gets the links of this PatchedansibleAnsibleNamespaceMetadata.  # noqa: E501

        Labeled related links.  # noqa: E501

        :return: The links of this PatchedansibleAnsibleNamespaceMetadata.  # noqa: E501
        :rtype: list[NamespaceLink]
        """
        return self._links

    @links.setter
    def links(self, links):
        """Sets the links of this PatchedansibleAnsibleNamespaceMetadata.

        Labeled related links.  # noqa: E501

        :param links: The links of this PatchedansibleAnsibleNamespaceMetadata.  # noqa: E501
        :type: list[NamespaceLink]
        """

        self._links = links

    @property
    def avatar(self):
        """Gets the avatar of this PatchedansibleAnsibleNamespaceMetadata.  # noqa: E501

        Optional avatar image for Namespace  # noqa: E501

        :return: The avatar of this PatchedansibleAnsibleNamespaceMetadata.  # noqa: E501
        :rtype: file
        """
        return self._avatar

    @avatar.setter
    def avatar(self, avatar):
        """Sets the avatar of this PatchedansibleAnsibleNamespaceMetadata.

        Optional avatar image for Namespace  # noqa: E501

        :param avatar: The avatar of this PatchedansibleAnsibleNamespaceMetadata.  # noqa: E501
        :type: file
        """

        self._avatar = avatar

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PatchedansibleAnsibleNamespaceMetadata):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PatchedansibleAnsibleNamespaceMetadata):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages  # noqa: E501

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from pulpcore.client.pulp_ansible.configuration import Configuration


class AnsibleRepositorySignature(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'content_units': 'list[object]',
        'signing_service': 'str'
    }

    attribute_map = {
        'content_units': 'content_units',
        'signing_service': 'signing_service'
    }

    def __init__(self, content_units=None, signing_service=None, local_vars_configuration=None):  # noqa: E501
        """AnsibleRepositorySignature - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._content_units = None
        self._signing_service = None
        self.discriminator = None

        self.content_units = content_units
        self.signing_service = signing_service

    @property
    def content_units(self):
        """Gets the content_units of this AnsibleRepositorySignature.  # noqa: E501

        List of collection version hrefs to sign, use * to sign all content in repository  # noqa: E501

        :return: The content_units of this AnsibleRepositorySignature.  # noqa: E501
        :rtype: list[object]
        """
        return self._content_units

    @content_units.setter
    def content_units(self, content_units):
        """Sets the content_units of this AnsibleRepositorySignature.

        List of collection version hrefs to sign, use * to sign all content in repository  # noqa: E501

        :param content_units: The content_units of this AnsibleRepositorySignature.  # noqa: E501
        :type: list[object]
        """
        if self.local_vars_configuration.client_side_validation and content_units is None:  # noqa: E501
            raise ValueError("Invalid value for `content_units`, must not be `None`")  # noqa: E501

        self._content_units = content_units

    @property
    def signing_service(self):
        """Gets the signing_service of this AnsibleRepositorySignature.  # noqa: E501

        A signing service to use to sign the collections  # noqa: E501

        :return: The signing_service of this AnsibleRepositorySignature.  # noqa: E501
        :rtype: str
        """
        return self._signing_service

    @signing_service.setter
    def signing_service(self, signing_service):
        """Sets the signing_service of this AnsibleRepositorySignature.

        A signing service to use to sign the collections  # noqa: E501

        :param signing_service: The signing_service of this AnsibleRepositorySignature.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and signing_service is None:  # noqa: E501
            raise ValueError("Invalid value for `signing_service`, must not be `None`")  # noqa: E501

        self._signing_service = signing_service

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AnsibleRepositorySignature):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AnsibleRepositorySignature):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages  # noqa: E501

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import pulpcore.client.pulp_ansible
from pulpcore.client.pulp_ansible.models.paginated_collection_version_search_list_response_list import PaginatedCollectionVersionSearchListResponseList  # noqa: E501
from pulpcore.client.pulp_ansible.rest import ApiException

class TestPaginatedCollectionVersionSearchListResponseList(unittest.TestCase):
    """PaginatedCollectionVersionSearchListResponseList unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test PaginatedCollectionVersionSearchListResponseList
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = pulpcore.client.pulp_ansible.models.paginated_collection_version_search_list_response_list.PaginatedCollectionVersionSearchListResponseList()  # noqa: E501
        if include_optional :
            return PaginatedCollectionVersionSearchListResponseList(
                meta = pulpcore.client.pulp_ansible.models.paginated_collection_response_list_meta.PaginatedCollectionResponseList_meta(
                    count = 123, ), 
                links = pulpcore.client.pulp_ansible.models.paginated_collection_response_list_links.PaginatedCollectionResponseList_links(
                    first = '0', 
                    previous = '0', 
                    next = '0', 
                    last = '0', ), 
                data = [
                    pulpcore.client.pulp_ansible.models.collection_version_search_list_response.CollectionVersionSearchListResponse(
                        repository = pulpcore.client.pulp_ansible.models.repository_response.RepositoryResponse(
                            pulp_href = '0', 
                            pulp_created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            versions_href = '0', 
                            pulp_labels = {
                                'key' : '0'
                                }, 
                            latest_version_href = '0', 
                            name = '0', 
                            description = '0', 
                            retain_repo_versions = 1, 
                            remote = '0', ), 
                        collection_version = pulpcore.client.pulp_ansible.models.collection_summary_response.CollectionSummaryResponse(
                            pulp_href = '0', 
                            namespace = '0', 
                            name = '0', 
                            version = '0', 
                            requires_ansible = '0', 
                            pulp_created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            contents = pulpcore.client.pulp_ansible.models.contents.contents(), 
                            dependencies = pulpcore.client.pulp_ansible.models.dependencies.dependencies(), 
                            description = '0', 
                            tags = [
                                pulpcore.client.pulp_ansible.models.ansible/tag_response.ansible.TagResponse(
                                    name = '0', )
                                ], ), 
                        repository_version = '0', 
                        namespace_metadata = null, 
                        is_highest = True, 
                        is_deprecated = True, 
                        is_signed = True, )
                    ]
            )
        else :
            return PaginatedCollectionVersionSearchListResponseList(
        )

    def testPaginatedCollectionVersionSearchListResponseList(self):
        """Test PaginatedCollectionVersionSearchListResponseList"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages  # noqa: E501

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from pulpcore.client.pulp_ansible.api_client import ApiClient
from pulpcore.client.pulp_ansible.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class PulpAnsibleApiV3PluginAnsibleSearchCollectionVersionsApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def list(self, path,  **kwargs):  # noqa: E501
        """list  # noqa: E501

        A viewset for cross-repo searches.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list(path, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str path: (required)
        :param str dependency:
        :param bool deprecated:
        :param list[str] distribution: Filter collectionversions that are in these distrubtion ids.
        :param list[str] distribution_base_path: Filter collectionversions that are in these base paths.
        :param bool highest:
        :param bool is_deprecated:
        :param bool is_highest:
        :param bool is_signed:
        :param str keywords:
        :param int limit: Number of results to return per page.
        :param str name:
        :param str namespace:
        :param int offset: The initial index from which to return the results.
        :param list[str] order_by: Ordering  * `pulp_created` - by CV created * `-pulp_created` - by CV created (descending) * `namespace` - by CV namespace * `-namespace` - by CV namespace (descending) * `name` - by CV name * `-name` - by CV name (descending) * `version` - by CV version * `-version` - by CV version (descending)
        :param str q:
        :param list[str] repository: Filter collectionversions that are in these repository ids.
        :param str repository_label: Filter labels by search string
        :param list[str] repository_name: Filter collectionversions that are in these repositories.
        :param str repository_version:
        :param bool signed:
        :param str tags: Filter by comma separate list of tags that must all be matched
        :param str version:
        :param str version_range:
        :param list[str] fields: A list of fields to include in the response.
        :param list[str] exclude_fields: A list of fields to exclude from the response.
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: PaginatedCollectionVersionSearchListResponseList
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.list_with_http_info(path,  **kwargs)  # noqa: E501

    def list_with_http_info(self, path,  **kwargs):  # noqa: E501
        """list  # noqa: E501

        A viewset for cross-repo searches.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_with_http_info(path, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str path: (required)
        :param str dependency:
        :param bool deprecated:
        :param list[str] distribution: Filter collectionversions that are in these distrubtion ids.
        :param list[str] distribution_base_path: Filter collectionversions that are in these base paths.
        :param bool highest:
        :param bool is_deprecated:
        :param bool is_highest:
        :param bool is_signed:
        :param str keywords:
        :param int limit: Number of results to return per page.
        :param str name:
        :param str namespace:
        :param int offset: The initial index from which to return the results.
        :param list[str] order_by: Ordering  * `pulp_created` - by CV created * `-pulp_created` - by CV created (descending) * `namespace` - by CV namespace * `-namespace` - by CV namespace (descending) * `name` - by CV name * `-name` - by CV name (descending) * `version` - by CV version * `-version` - by CV version (descending)
        :param str q:
        :param list[str] repository: Filter collectionversions that are in these repository ids.
        :param str repository_label: Filter labels by search string
        :param list[str] repository_name: Filter collectionversions that are in these repositories.
        :param str repository_version:
        :param bool signed:
        :param str tags: Filter by comma separate list of tags that must all be matched
        :param str version:
        :param str version_range:
        :param list[str] fields: A list of fields to include in the response.
        :param list[str] exclude_fields: A list of fields to exclude from the response.
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(PaginatedCollectionVersionSearchListResponseList, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'path',
            'dependency',
            'deprecated',
            'distribution',
            'distribution_base_path',
            'highest',
            'is_deprecated',
            'is_highest',
            'is_signed',
            'keywords',
            'limit',
            'name',
            'namespace',
            'offset',
            'order_by',
            'q',
            'repository',
            'repository_label',
            'repository_name',
            'repository_version',
            'signed',
            'tags',
            'version',
            'version_range',
            'fields',
            'exclude_fields'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method list" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'path' is set
        if self.api_client.client_side_validation and ('path' not in local_var_params or  # noqa: E501
                                                        local_var_params['path'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `path` when calling `list`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'path' in local_var_params:
            path_params['path'] = local_var_params['path']  # noqa: E501

        query_params = []
        if 'dependency' in local_var_params and local_var_params['dependency'] is not None:  # noqa: E501
            query_params.append(('dependency', local_var_params['dependency']))  # noqa: E501
        if 'deprecated' in local_var_params and local_var_params['deprecated'] is not None:  # noqa: E501
            query_params.append(('deprecated', local_var_params['deprecated']))  # noqa: E501
        if 'distribution' in local_var_params and local_var_params['distribution'] is not None:  # noqa: E501
            query_params.append(('distribution', local_var_params['distribution']))  # noqa: E501
            collection_formats['distribution'] = 'multi'  # noqa: E501
        if 'distribution_base_path' in local_var_params and local_var_params['distribution_base_path'] is not None:  # noqa: E501
            query_params.append(('distribution_base_path', local_var_params['distribution_base_path']))  # noqa: E501
            collection_formats['distribution_base_path'] = 'multi'  # noqa: E501
        if 'highest' in local_var_params and local_var_params['highest'] is not None:  # noqa: E501
            query_params.append(('highest', local_var_params['highest']))  # noqa: E501
        if 'is_deprecated' in local_var_params and local_var_params['is_deprecated'] is not None:  # noqa: E501
            query_params.append(('is_deprecated', local_var_params['is_deprecated']))  # noqa: E501
        if 'is_highest' in local_var_params and local_var_params['is_highest'] is not None:  # noqa: E501
            query_params.append(('is_highest', local_var_params['is_highest']))  # noqa: E501
        if 'is_signed' in local_var_params and local_var_params['is_signed'] is not None:  # noqa: E501
            query_params.append(('is_signed', local_var_params['is_signed']))  # noqa: E501
        if 'keywords' in local_var_params and local_var_params['keywords'] is not None:  # noqa: E501
            query_params.append(('keywords', local_var_params['keywords']))  # noqa: E501
        if 'limit' in local_var_params and local_var_params['limit'] is not None:  # noqa: E501
            query_params.append(('limit', local_var_params['limit']))  # noqa: E501
        if 'name' in local_var_params and local_var_params['name'] is not None:  # noqa: E501
            query_params.append(('name', local_var_params['name']))  # noqa: E501
        if 'namespace' in local_var_params and local_var_params['namespace'] is not None:  # noqa: E501
            query_params.append(('namespace', local_var_params['namespace']))  # noqa: E501
        if 'offset' in local_var_params and local_var_params['offset'] is not None:  # noqa: E501
            query_params.append(('offset', local_var_params['offset']))  # noqa: E501
        if 'order_by' in local_var_params and local_var_params['order_by'] is not None:  # noqa: E501
            query_params.append(('order_by', local_var_params['order_by']))  # noqa: E501
            collection_formats['order_by'] = 'csv'  # noqa: E501
        if 'q' in local_var_params and local_var_params['q'] is not None:  # noqa: E501
            query_params.append(('q', local_var_params['q']))  # noqa: E501
        if 'repository' in local_var_params and local_var_params['repository'] is not None:  # noqa: E501
            query_params.append(('repository', local_var_params['repository']))  # noqa: E501
            collection_formats['repository'] = 'multi'  # noqa: E501
        if 'repository_label' in local_var_params and local_var_params['repository_label'] is not None:  # noqa: E501
            query_params.append(('repository_label', local_var_params['repository_label']))  # noqa: E501
        if 'repository_name' in local_var_params and local_var_params['repository_name'] is not None:  # noqa: E501
            query_params.append(('repository_name', local_var_params['repository_name']))  # noqa: E501
            collection_formats['repository_name'] = 'multi'  # noqa: E501
        if 'repository_version' in local_var_params and local_var_params['repository_version'] is not None:  # noqa: E501
            query_params.append(('repository_version', local_var_params['repository_version']))  # noqa: E501
        if 'signed' in local_var_params and local_var_params['signed'] is not None:  # noqa: E501
            query_params.append(('signed', local_var_params['signed']))  # noqa: E501
        if 'tags' in local_var_params and local_var_params['tags'] is not None:  # noqa: E501
            query_params.append(('tags', local_var_params['tags']))  # noqa: E501
        if 'version' in local_var_params and local_var_params['version'] is not None:  # noqa: E501
            query_params.append(('version', local_var_params['version']))  # noqa: E501
        if 'version_range' in local_var_params and local_var_params['version_range'] is not None:  # noqa: E501
            query_params.append(('version_range', local_var_params['version_range']))  # noqa: E501
        if 'fields' in local_var_params and local_var_params['fields'] is not None:  # noqa: E501
            query_params.append(('fields', local_var_params['fields']))  # noqa: E501
            collection_formats['fields'] = 'multi'  # noqa: E501
        if 'exclude_fields' in local_var_params and local_var_params['exclude_fields'] is not None:  # noqa: E501
            query_params.append(('exclude_fields', local_var_params['exclude_fields']))  # noqa: E501
            collection_formats['exclude_fields'] = 'multi'  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'cookieAuth']  # noqa: E501

        return self.api_client.call_api(
            '/pulp_ansible/galaxy/{path}/api/v3/plugin/ansible/search/collection-versions/', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='PaginatedCollectionVersionSearchListResponseList',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def rebuild(self, path, collection_version_search_list,  **kwargs):  # noqa: E501
        """rebuild  # noqa: E501

        A viewset for cross-repo searches.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.rebuild(path, collection_version_search_list, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str path: (required)
        :param CollectionVersionSearchList collection_version_search_list: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: CollectionVersionSearchListResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.rebuild_with_http_info(path, collection_version_search_list,  **kwargs)  # noqa: E501

    def rebuild_with_http_info(self, path, collection_version_search_list,  **kwargs):  # noqa: E501
        """rebuild  # noqa: E501

        A viewset for cross-repo searches.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.rebuild_with_http_info(path, collection_version_search_list, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str path: (required)
        :param CollectionVersionSearchList collection_version_search_list: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(CollectionVersionSearchListResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'path',
            'collection_version_search_list'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method rebuild" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'path' is set
        if self.api_client.client_side_validation and ('path' not in local_var_params or  # noqa: E501
                                                        local_var_params['path'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `path` when calling `rebuild`")  # noqa: E501
        # verify the required parameter 'collection_version_search_list' is set
        if self.api_client.client_side_validation and ('collection_version_search_list' not in local_var_params or  # noqa: E501
                                                        local_var_params['collection_version_search_list'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `collection_version_search_list` when calling `rebuild`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'path' in local_var_params:
            path_params['path'] = local_var_params['path']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'collection_version_search_list' in local_var_params:
            body_params = local_var_params['collection_version_search_list']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'cookieAuth']  # noqa: E501

        return self.api_client.call_api(
            '/pulp_ansible/galaxy/{path}/api/v3/plugin/ansible/search/collection-versions/', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='CollectionVersionSearchListResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)
